==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/j4o/lang/reflect/Method.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Reflection;

namespace j4o.lang.reflect
{
    public class Method
	{
        private MethodInfo _methodInfo;

        internal Method(MethodInfo methodInfo)
		{
            this._methodInfo = methodInfo;
        }

		internal MethodInfo MethodInfo
		{
			get { return _methodInfo; }
		}

        public Object invoke(Object obj, Object[] args)
		{
            return _methodInfo.Invoke(obj, args);
        }

        public String getName()
		{
            return _methodInfo.Name;
        }

		public j4o.lang.Class[] getParameterTypes() 
		{
			ParameterInfo[] parameters = _methodInfo.GetParameters();
			j4o.lang.Class[] types = new j4o.lang.Class[parameters.Length];
			for (int i=0; i<parameters.Length; ++i)
			{
				types[i] = j4o.lang.Class.getClassForType(parameters[i].ParameterType);
			}
			return types;
		}

		public j4o.lang.Class getReturnType() 
		{
			return j4o.lang.Class.getClassForType(_methodInfo.ReturnType);
		}
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/j4o/lang/reflect/Method.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Reflection;

namespace j4o.lang.reflect
{
    public class Method
	{
        private MethodInfo _methodInfo;

        internal Method(MethodInfo methodInfo)
		{
            this._methodInfo = methodInfo;
        }

		internal MethodInfo MethodInfo
		{
			get { return _methodInfo; }
		}

        public Object Invoke(Object obj, Object[] args)
		{
            return _methodInfo.Invoke(obj, args);
        }

        public String GetName()
		{
            return _methodInfo.Name;
        }

		public j4o.lang.Class[] GetParameterTypes() 
		{
			ParameterInfo[] parameters = _methodInfo.GetParameters();
			j4o.lang.Class[] types = new j4o.lang.Class[parameters.Length];
			for (int i=0; i<parameters.Length; ++i)
			{
				types[i] = j4o.lang.Class.GetClassForType(parameters[i].ParameterType);
			}
			return types;
		}

		public j4o.lang.Class GetReturnType() 
		{
			return j4o.lang.Class.GetClassForType(_methodInfo.ReturnType);
		}
    }
}
